tiled.media\_type\_registration.SerializationRegistry.aliases
=============================================================

.. currentmodule:: tiled.media_type_registration

.. automethod:: SerializationRegistry.aliases